==> jc-1.4.0.tar.gz: java/rmi/server/RemoteServer.h <==
// public abstract class java.rmi.server.RemoteServer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer

// header file dependencies
// @dep_header java_rmi_server_RemoteObject

#include "java/rmi/server/RemoteObject.h"

#ifndef _JC_java_rmi_server_RemoteServer_H_
#define _JC_java_rmi_server_RemoteServer_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_RemoteRef$object;

// Typedefs
typedef struct _jc_java_rmi_server_RemoteServer$sub_refs	_jc_java_rmi_server_RemoteServer$sub_refs;
typedef struct _jc_java_rmi_server_RemoteServer$sub_nonrefs	_jc_java_rmi_server_RemoteServer$sub_nonrefs;
typedef struct _jc_java_rmi_server_RemoteServer$refs	_jc_java_rmi_server_RemoteServer$refs;
typedef struct _jc_java_rmi_server_RemoteServer$nonrefs	_jc_java_rmi_server_RemoteServer$nonrefs;
typedef struct _jc_java_rmi_server_RemoteServer$object	_jc_java_rmi_server_RemoteServer$object;

typedef struct _jc_java_rmi_server_RemoteServer$fields_struct	_jc_java_rmi_server_RemoteServer$fields_struct;
typedef const struct _jc_java_rmi_server_RemoteServer$vmethods	_jc_java_rmi_server_RemoteServer$vmethods;
typedef const struct _jc_java_rmi_server_RemoteServer$vtable	_jc_java_rmi_server_RemoteServer$vtable;
typedef const struct _jc_java_rmi_server_RemoteServer$vtype	_jc_java_rmi_server_RemoteServer$vtype;

// Class fields structure
struct _jc_java_rmi_server_RemoteServer$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_RemoteServer$fields_struct _jc_java_rmi_server_RemoteServer$class_fields;

// Constructors
extern void _jc_java_rmi_server_RemoteServer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RemoteServer$object *);
extern void _jc_java_rmi_server_RemoteServer$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_java_rmi_server_RemoteServer$object *, struct _jc_object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RemoteServer$method$getClientHost$724d6b00474d82a0(_jc_env *);
extern struct _jc_java_io_PrintStream$object *_jc_java_rmi_server_RemoteServer$method$getLog$6b1b34ba864104a5(_jc_env *);
extern void _jc_java_rmi_server_RemoteServer$method$setLog$70a95c6575781d0b(_jc_env *, struct _jc_java_io_OutputStream$object *);

// Virtual methods structure
struct _jc_java_rmi_server_RemoteServer$vmethods {
};

// Vtable
struct _jc_java_rmi_server_RemoteServer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
};

// Vtype
struct _jc_java_rmi_server_RemoteServer$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RemoteServer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteServer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RemoteServer$refs {
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteServer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RemoteServer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
};

// Object instance structure
struct _jc_java_rmi_server_RemoteServer$object {
	_jc_java_rmi_server_RemoteServer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RemoteServer$vtype	*vtype;
	_jc_java_rmi_server_RemoteServer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RemoteServer$vtype _jc_java_rmi_server_RemoteServer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RemoteServer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RemoteServer$class_object;

#endif	/* _JC_java_rmi_server_RemoteServer_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/RemoteServer.h <==
// public abstract class java.rmi.server.RemoteServer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer

// header file dependencies
// @dep_header java_rmi_server_RemoteObject

#include "java/rmi/server/RemoteObject.h"

#ifndef _JC_java_rmi_server_RemoteServer_H_
#define _JC_java_rmi_server_RemoteServer_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_RemoteRef$object;

// Typedefs
typedef struct _jc_java_rmi_server_RemoteServer$sub_refs	_jc_java_rmi_server_RemoteServer$sub_refs;
typedef struct _jc_java_rmi_server_RemoteServer$sub_nonrefs	_jc_java_rmi_server_RemoteServer$sub_nonrefs;
typedef struct _jc_java_rmi_server_RemoteServer$refs	_jc_java_rmi_server_RemoteServer$refs;
typedef struct _jc_java_rmi_server_RemoteServer$nonrefs	_jc_java_rmi_server_RemoteServer$nonrefs;
typedef struct _jc_java_rmi_server_RemoteServer$object	_jc_java_rmi_server_RemoteServer$object;

typedef struct _jc_java_rmi_server_RemoteServer$fields_struct	_jc_java_rmi_server_RemoteServer$fields_struct;
typedef const struct _jc_java_rmi_server_RemoteServer$vmethods	_jc_java_rmi_server_RemoteServer$vmethods;
typedef const struct _jc_java_rmi_server_RemoteServer$vtable	_jc_java_rmi_server_RemoteServer$vtable;
typedef const struct _jc_java_rmi_server_RemoteServer$vtype	_jc_java_rmi_server_RemoteServer$vtype;

// Class fields structure
struct _jc_java_rmi_server_RemoteServer$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_RemoteServer$fields_struct _jc_java_rmi_server_RemoteServer$class_fields;

// Constructors
extern void _jc_java_rmi_server_RemoteServer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RemoteServer$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_RemoteServer$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_java_rmi_server_RemoteServer$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RemoteServer$method$getClientHost$724d6b00474d82a0(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_io_PrintStream$object *_jc_java_rmi_server_RemoteServer$method$getLog$6b1b34ba864104a5(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_RemoteServer$method$setLog$70a95c6575781d0b(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_RemoteServer$vmethods {
};

// Vtable
struct _jc_java_rmi_server_RemoteServer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
};

// Vtype
struct _jc_java_rmi_server_RemoteServer$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RemoteServer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteServer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RemoteServer$refs {
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteServer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RemoteServer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
};

// Object instance structure
struct _jc_java_rmi_server_RemoteServer$object {
	_jc_java_rmi_server_RemoteServer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RemoteServer$vtype	*vtype;
	_jc_java_rmi_server_RemoteServer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RemoteServer$vtype _jc_java_rmi_server_RemoteServer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RemoteServer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RemoteServer$class_object;

#endif	/* _JC_java_rmi_server_RemoteServer_H_ */
